@@ -144,7 +144,7 @@ class Simulation:
         self.results = Mxy
         return self.results
 
-    def CalculateSVD(self, truncationNumber):
+    def CalculateSVD(self, desiredSVDPower=0.99, truncationNumberOverride=None):
         dictionary = self.results.transpose()
         dictionaryNorm = np.sqrt(np.sum(np.power(np.abs(dictionary[:,:]),2),1))
         dictionaryShape = np.shape(dictionary)
@@ -152,11 +152,16 @@ class Simulation:
         for i in range(dictionaryShape[0]):
             normalizedDictionary[i,:] = dictionary[i,:]/dictionaryNorm[i]
         (u,s,v) = np.linalg.svd(normalizedDictionary, full_matrices=False)
+        self.singularValues = s
+        if truncationNumberOverride == None:
+            (truncationNumber, totalSVDPower) = self.GetTruncationNumberFromDesiredPower(desiredSVDPower)
+        else:
+            truncationNumber = truncationNumberOverride
+            totalSVDPower = self.GetPowerFromDesiredTruncationNumber(truncationNumber)
         vt = np.transpose(v)
         self.truncationMatrix = vt[:,0:truncationNumber]
         self.truncatedResults = np.matmul(normalizedDictionary,self.truncationMatrix).transpose()
-        self.singularValues = s
-        return (u,s,v)
+        return (truncationNumber, totalSVDPower)
 
     def GetTruncationNumberFromDesiredPower(self, desiredSVDPower):
         singularVectorPowers = self.simulation.singularValues/np.sum(self.simulation.singularValues)
@@ -168,6 +173,11 @@ class Simulation:
                 break
         return numSVDComponents, totalSVDPower
 
+    def GetPowerFromDesiredTruncationNumber(self, desiredTruncationNumber):
+        singularVectorPowers = self.simulation.singularValues/np.sum(self.simulation.singularValues)
+        totalSVDPower=np.sum(singularVectorPowers[0:desiredTruncationNumber])
+        return totalSVDPower
+
     def Export(self, filename, force=False, includeFullResults=True, includeSVDResults=True):
         if ".mrf" in filename:
             outfile = h5py.File(filename, "a")
